==> payroll_ver_3.3.0.zip: payroll3/src/jp/mosp/payroll/human/action/HumanPersonalCardAction.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.payroll.human.action;

import jp.mosp.common.CommonConst;
import jp.mosp.human.action.HumanKihonCardAction;

/**
 * @author koike
 *
 */
public class HumanPersonalCardAction extends jp.mosp.human.action.HumanPersonalCardAction {
	
	/**
	 * 
	 */
	public HumanPersonalCardAction() {
		// TODO ꂽRXgN^[EX^u
		super();
	}
	
	/**
	 * @param isNewData
	 * @return
	 */
	/* ( Javadoc)
	 * @see jp.mosp.kintai.common.action.MosPHumanAction#getFunctionArray(boolean)
	 */
	@Override
	protected String[][] getFunctionArray(boolean isNewData) {
		String[][] aryFunction = null;
		if (isNewData) {
			aryFunction = new String[][]{ { "btnNewData", HumanKihonCardAction.CMD_HUMAN_BASIS_SHOW,
				CommonConst.NAM_MAKE_NEW_DATA }, };
		} else {
			aryFunction = new String[][]{
				{ "btnBasic", HumanKihonCardAction.CMD_HUMAN_BASIS_SELECT, CommonConst.NAM_EDIT_HUMAN_BASIC },
				{ "btnKojin", HumanPersonalCardAction.CMD_HUMAN_PERSONAL_SELECT, CommonConst.NAM_EDIT_HUMAN_KOJIN },
				{ "btnCalc", "U4150", "^ҏW" }, };
		}
		return aryFunction;
	}
}

==> payroll_ver_3.3.3.zip: payroll3/src/jp/mosp/payroll/human/action/HumanPersonalCardAction.java <==
/*
 * MosP - Mind Open Source Project    http://www.mosp.jp/
 * Copyright (C) MIND Co., Ltd.       http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.payroll.human.action;

import jp.mosp.common.CommonConst;

/**
 * @author koike
 *
 */
public class HumanPersonalCardAction extends jp.mosp.kintai.human.action.HumanPersonalCardAction {
	
	/**
	 * 
	 */
	public HumanPersonalCardAction() {
		// TODO ꂽRXgN^[EX^u
		super();
	}
	
	/**
	 * @param isNewData
	 * @return
	 */
	/* ( Javadoc)
	 * @see jp.mosp.kintai.common.action.MosPHumanAction#getFunctionArray(boolean)
	 */
	@Override
	protected String[][] getFunctionArray(boolean isNewData) {
		String[][] aryFunction = null;
		if (isNewData) {
			aryFunction = new String[][]{ { "btnNewData", HumanKihonCardAction.CMD_HUMAN_BASIS_SHOW,
				CommonConst.NAM_MAKE_NEW_DATA }, };
		} else {
			aryFunction = new String[][]{
				{ "btnBasic", HumanKihonCardAction.CMD_HUMAN_BASIS_SELECT, CommonConst.NAM_EDIT_HUMAN_BASIC },
				{ "btnKojin", HumanPersonalCardAction.CMD_HUMAN_PERSONAL_SELECT, CommonConst.NAM_EDIT_HUMAN_KOJIN },
				{ "btnCalc", "U4150", "^ҏW" }, };
		}
		return aryFunction;
	}
}
